@@ -1,14 +1,12 @@
 
-from prettyexc import PrettyException
-
-class AuthenticationError(PrettyException):
-    pass
+from .exceptions import *
 
 class Authentication(object):
-    def __init__(self, cryptor, verifier, coder, session_handler, secret_key):
+    def __init__(self, cryptor, verifier, datacoder, session_handler, secret_key):
+        #self.streamcoder = streamcoder
         self.cryptor = cryptor
         self.verifier = verifier
-        self.coder = coder
+        self.coder = datacoder
         self.session_handler = session_handler
         self.secret_key = secret_key
 
@@ -29,9 +27,9 @@ class Authentication(object):
                     cryptor
                        V
         | #2 Receiver-Decrypted Raw Data | --verifier--> | Public Key |
-                      |                                        |
-                   verifier                                    V
-                      V                                        |
+                       |                                       |
+                    verifier                                   V
+                       V                                       |
           | #3 Sender-Encrypted Data | ---------->-------------+
                                                                |
                                                             cryptor
